#-------------------------------------------------------------------------------
# Name:        large_var_gen
# Purpose:
#
# Author:      Leo Hendrawan
#
# Created:     09.07.2012
# Copyright:   -
# Licence:     BSD license
#-------------------------------------------------------------------------------
#!/usr/bin/env python

def large_var_gen():
    f = open('large_var.h', 'w')

    # print variable name
    f.write("const unsigned char large_var[] = {\n")

    # initialize device dictionary - key: device name - value: memory size
    Devs = {}
    Devs['CC430F6137'] = 32
    Devs['MSP430F1232'] = 8
    Devs['MSP430F149'] = 60
    Devs['MSP430F1612'] = 55
    Devs['MSP430F2274'] = 32
    Devs['MSP430F249'] = 60
    Devs['MSP430F2619'] = 120
    Devs['MSP430F449'] = 60
    Devs['MSP430F47187'] = 116
    Devs['MSP430FG4619'] = 120
    Devs['MSP430F5172'] = 32
    Devs['MSP430F5342'] = 128
    Devs['MSP430F5438A'] = 256
    Devs['MSP430FR5739'] = 16
    Devs['MSP430G2553'] = 16
    num_of_devs = len(Devs)

    var_size = 60 * 1024 # 60k variable (maximum)
    total_bytes = range (var_size)
    col = 1
    bytes = 0
    num_of_macroline = 0
    line_string = "  "
    for i in total_bytes:
        str_hex = "0x%02.x" % bytes
        line_string += str_hex
        # add comma or print line
        if i < var_size-1:
            line_string += ", "
        if col == 64:
            line_string += "\n"
            f.write(line_string)
            line_string = "  "
            col = 1
        else:
            col += 1

        # increment bytes
        if bytes == 255:
            bytes = 0
        else:
            bytes += 1

        # add macro if necessary
        if i % 1024 == 0:
            macro_str = get_macro_head(Devs, i/1024)
            if macro_str != "":
                f.write(macro_str + "\n")
                num_of_macroline += 1

    # print ending
    for i in range(num_of_macroline):
        f.write ("#endif\n");
    f.write("};\n")

#-------------------------------------------------------------------------------

def get_macro_head(Devs, size_kb):
    ret_string = ""
    cnt = 0
    for dev in Devs.items():
        if dev[1]-2 == size_kb:
            if cnt == 0:
                ret_string = "#if"
            else:
                ret_string += " && "
            ret_string += " (!defined __" + dev[0] + "__)"
            cnt += 1
    return ret_string

#-------------------------------------------------------------------------------

if __name__ == '__main__':
    large_var_gen()
